aboutsummaryrefslogtreecommitdiff
path: root/src/vendorcode/google/chromeos/vboot2/vboot_logic.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/vendorcode/google/chromeos/vboot2/vboot_logic.c')
-rw-r--r--src/vendorcode/google/chromeos/vboot2/vboot_logic.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/vendorcode/google/chromeos/vboot2/vboot_logic.c b/src/vendorcode/google/chromeos/vboot2/vboot_logic.c
index a81a9c2892..116c9498d9 100644
--- a/src/vendorcode/google/chromeos/vboot2/vboot_logic.c
+++ b/src/vendorcode/google/chromeos/vboot2/vboot_logic.c
@@ -301,8 +301,12 @@ void verstage_main(void)
/* Set up context and work buffer */
vb2_init_work_context(&ctx);
- /* Read nvdata from a non-volatile storage */
- read_vbnv(ctx.nvdata);
+ /*
+ * Read nvdata from a non-volatile storage and mark data as changed
+ * if instructed.
+ */
+ if (read_vbnv(ctx.nvdata))
+ ctx.flags |= VB2_CONTEXT_NVDATA_CHANGED;
/* Set S3 resume flag if vboot should behave differently when selecting
* which slot to boot. This is only relevant to vboot if the platform